#
# spec file for package cscreen
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define USERNAME _cscreen
%define HOMEDIR %_localstatedir/lib/cscreen
Name:           cscreen
Version:        1.8
Release:        1.2
Summary:        Console screen
License:        BSD-4-Clause
Group:          System/Management
URL:            https://github.com/openSUSE/cscreen
Source:         %name-%version.tar.xz
Source1:        %name-rpmlintrc
BuildRequires:  sudo
Recommends:     logrotate
Requires:       screen
Requires:       sudo
Requires(postun): coreutils
BuildRequires:  pkgconfig(systemd)
BuildRequires:  sysuser-tools
Requires(pre):  system-user-%name = %version-%release
%{?systemd_ordering}
BuildArch:      noarch

%description
This package allows to run multiple consoles in one 'screen' and
to start the screen automatically during boot.

%package -n system-user-%name
Summary:        System user %USERNAME
%if 0%{?suse_version} > 1320
Requires(pre):  group(dialout)
Requires(pre):  group(tty)
%endif
%?sysusers_requires

%description -n system-user-%name
System user %USERNAME

%prep
%autosetup -p1
#
%build
#
%install
> %name.files
if ! test -d %_sysconfdir/sudoers.d
then
  echo '%%dir %_sysconfdir/sudoers.d' >> %name.files
fi
mkdir -p %buildroot/%_sbindir

install -Dm644 cscreen.service %buildroot/%_unitdir/cscreend.service
pushd %buildroot/%_sbindir
ln -sf service %buildroot%_sbindir/rccscreend
popd
mkdir -vp %buildroot%_tmpfilesdir
tee %buildroot%_tmpfilesdir/%name.conf <<'_EOF_'
d %_rundir/%name 0750 %USERNAME %USERNAME -
_EOF_
suc='system-user-%name.conf'
tee "${suc}" <<'_EOC_'
u %USERNAME - "cscreen daemon user" %HOMEDIR /bin/bash
m %USERNAME dialout
m %USERNAME tty
_EOC_
mkdir -p '%buildroot%_sysusersdir'
cp -avLt "$_" "${suc}"
%sysusers_generate_pre "${suc}" system-user-%name

install -Dm640 configs/cscreen.config %buildroot/%_sysconfdir/cscreenrc
install -Dm644 configs/cscreen.logrotate %buildroot/%_sysconfdir/logrotate.d/%name
install -Dm644 configs/cscreen.sudoers %buildroot%_sysconfdir/sudoers.d/%name
install -Dm755 src/cscreen-shell %buildroot/%_datadir/%name/cscreen-shell
install -Dm555 src/sol-via-ipmi.sh %buildroot/%_datadir/%name/sol-via-ipmi.sh
install -Dm555 src/sol-via-ssh.sh %buildroot/%_datadir/%name/sol-via-ssh.sh
install -Dm755 src/cscreen %buildroot/%_bindir/%name
install -Dm755 src/cscreen_update_config.sh %buildroot/%_bindir/cscreen_update_config.sh

mkdir -p %buildroot%_localstatedir/log/screen/old
mkdir -pm700 %buildroot/%HOMEDIR
mkdir -pm700 %buildroot/%HOMEDIR/.ssh

%pre
%service_add_pre cscreend.service

%post
%service_add_post cscreend.service
%tmpfiles_create %_tmpfilesdir/%name.conf

%preun
%service_del_preun cscreend.service

%postun
%if %{defined service_del_postun_without_restart}
%service_del_postun_without_restart cscreend.service
%else
DISABLE_RESTART_ON_UPDATE=yes
%service_del_postun cscreend.service
%endif
if [ -d %_rundir/uscreens/S-cscreen ];then
    if [ "$1" = "0" ];then
	# Only delete on uninstall
	rm -rf %_rundir/uscreens/S-cscreen
    fi
fi

%pre -n system-user-%name -f system-user-%name.pre
%files -n system-user-%name
%_sysusersdir/*.conf

%files -f %name.files
%doc README.md
%doc docs/motd_example
%if 0%{?suse_version} > 1320
%license License
%endif
%_bindir/%name
%_bindir/cscreen_update_config.sh
%_datadir/%name
%_tmpfilesdir/%name.conf
%_unitdir/cscreend.service
%_sbindir/rccscreend

%attr(0640,root,root) %config %_sysconfdir/sudoers.d/%name
%attr(755,%{USERNAME}, %{USERNAME}) %dir %_localstatedir/log/screen
%attr(755,%{USERNAME}, %{USERNAME}) %dir %_localstatedir/log/screen/old
%attr(700,%{USERNAME}, %{USERNAME}) %dir %HOMEDIR
%attr(700,%{USERNAME}, %{USERNAME}) %dir %HOMEDIR/.ssh
%attr(644,%{USERNAME}, %{USERNAME}) %config(noreplace) %_sysconfdir/cscreenrc
%config(noreplace) %_sysconfdir/logrotate.d/%name

%changelog
* Mon Mar 18 2024 olaf@aepfle.de
- version 1.8
- disable screen and colon command in example cscreenrc
- reduce the default nice level to 3 for entire screen session
- provide sol-via-impi.sh and sol-via-ssh.sh
* Thu Mar 14 2024 olaf@aepfle.de
- version 1.7
- screen uses select(2), which is limited to FD_SETSIZE open file descriptors
* Fri Mar  8 2024 olaf@aepfle.de
- version 1.6
- Fix sysusers.d usage to make system-user-cscreen installable
- Remove pre-systemd support
* Mon Feb  5 2024 olaf@aepfle.de
- version 1.5
- Create system-user-cscreen
- add example for virsh console (bsc#1213936)
* Wed Mar  9 2022 olaf@aepfle.de
- version 1.4
- remove braces from rpm macros
- expand %%name in rpm specfile for some files
- Include new tmpfile in files section
* Wed Mar  9 2022 olaf@aepfle.de
- version 1.3
- restrict usage of cscreen to a trusted set of users (bsc#1196451, CVE-2022-21946)
- remove usage of fixed path /tmp/cscreen.debug (bsc#1196446, CVE-2022-21945)
* Mon Sep 27 2021 olaf@aepfle.de
- version 1.2
- fix default logtstamp string
* Wed Apr 21 2021 olaf@aepfle.de
- version 1.1
- set hard status in cscreenrc example
- use wrapper script for shell/SHELL
- fix screen execution
* Tue Apr 20 2021 olaf@aepfle.de
- version 1.0
- start cscreen earlier by ordering it right after local-fs.target
- add zombie_timeout to default cscreenrc
- adjust Requires for scriptlets
- package cscreen-rpmlintrc
- Set LimitNOFILE= to compensate for lack of SCREEN_FILE_LIMIT
- use fillup and sysconfig only with sysv
- fillup file should be owned by root
- use DISABLE_RESTART_ON_UPDATE also with sysv
- %%license macro does not work reliably in 13.2
- check if rpm macro has_systemd exists
- own suders.d if needed
- use name macro consistently
- remove Requires for apparently unused mailx
- use screen variable in cscreen script
- use SCREEN_OWNER in cscreen script
- use SCREENRC variable consistently
- use SCREEN_NAME variable consistently
- remove leading slash from sysv SCREEN_NAME
- move defscrollback to SCREEN_HISTORY
- Pass more characters to the remote system (bsc#1162835).
- Get rid of /etc/sudoers.d directory to avoid file conflicts at install time
* Fri Sep 11 2020 Franck Bui <fbui@suse.com>
- Make use of %%service_del_postun_without_restart
  And stop using DISABLE_RESTART_ON_UPDATE as this interface is
  obsolete.
* Tue Aug 25 2020 olaf@aepfle.de
- version 0.8
- Fix shell syntax in FORCE_UPDATE test
- add defattr
- Wrap %%license
- add BuildRoot
- Move lock file from /etc/cscreenrc_allow_update to /dev/shm/.cscreenrc_allow_update
- Set DISABLE_RESTART_ON_UPDATE=yes
- carry permissions of sudoers.d content
- Remove BuildRequires screen and sudo
- Add hint how to use SCREEN_OWNER with systemd
- Adjust default username in sysv rccscreen
- Adjust comment in cscreen to refer to default username
- mark sudoers as config to preserve local modifications
- Use correct user _cscreen for logrotate.conf
- Add execute permissions to /var/log/screen
* Mon Aug 24 2020 olaf@aepfle.de
- Adjust permissions for ~_cscreen
* Wed Jun 10 2020 Thomas Renninger <trenn@suse.de>
- Do not try to chmod  /run/uscreens/S-cscreen on update
- avoid bashism in postun
- Require(postun) rm instead of coreutils
* Tue Jun  9 2020 Thomas Renninger <trenn@suse.de>
- Use %%{?systemd_ordering}, pkgconfig(systemd)
- Only recommend logrotate, do not require it
- In case of update try to chmod to _cscreen user instead of
  deleting /run/uscreens/S-cscreen
* Tue Jun  9 2020 Thomas Renninger <trenn@suse.de>
- Pushed cscreen stuff to https://github.com/openSUSE/cscreen
  added _service file and pumped version to latest release v0.7
* Wed May 13 2020 Thomas Renninger <trenn@suse.de>
- Introduce cscreen to run as _cscreen user instead of root
- Update to version 0.6
* Mon May 11 2020 Thomas Renninger <trenn@suse.de>
- Run through spec-cleaner
- Update to version 0.5
* Thu May  7 2020 ohering@suse.de
- Usage of cscreen requires sudo
- Remove stale comments, mark cscreenrc as ready to use
* Thu Nov  7 2019 trenn@suse.de
- Add live updating possibilities (adding, removing windows actively)
  which is needed for orthos
* Mon Oct 21 2019 Lars.Vogdt@suse.com
- try to exit screen normally first, before killing (init script only)
* Wed Oct 24 2018 ro@suse.de
- add autofs.service to After: list in systemd unit file
* Mon Oct 22 2018 ro@suse.de
- fix cscreen script to read sysconfig/cscreen
- link rcfile to service
* Mon Apr  9 2018 ro@suse.de
- fix fillup dir usage
* Mon Aug 21 2017 lrupp@suse.de
- adapt config:
  + defscrollback is now 20000 per default
  + disable startup message
  + enable logging
- remove cscreen.1 manpage snipplets: manpage is missing anyway
* Mon Jan 23 2017 Lars.Vogdt@suse.com
- add fillup_only for the sysconfig script
* Fri Jul 22 2016 mcaj@suse.com
- added working systemd file for cscreen.
* Fri Feb 12 2016 ro@suse.de
- update cscreen with code from sconsole1 to allow cscreen -u
* Thu Jul 17 2014 mcaj@suse.com
- Fixed licence warning.
- added %%preun and %%postun parts.
* Wed Nov 23 2011 lrupp@suse.de
- use olddir /var/log/screen/old
- use /etc/cscreenrc as config
- added cscreen.sysconfig to have the configuration configurable
* Tue Jul 12 2011 lrupp@suse.de
- add /usr/bin/cscreen
* Fri Jan 14 2011 lrupp@suse.de
- own and create /var/log/screen
* Sun Nov 21 2010 lrupp@suse.de
- initial version 0.1
